@@ -1,7 +1,9 @@
 test_that("str_trim_anything works", {
   expect_equal(str_trim_anything("..abcd.", coll("."), "left"), "abcd.")
-  expect_equal(str_trim_anything("..abcd.", coll("."), "Ri"),
-               str_trim_anything("..abcd.", coll("."), "r"))
+  expect_equal(
+    str_trim_anything("..abcd.", coll("."), "Ri"),
+    str_trim_anything("..abcd.", coll("."), "r")
+  )
   expect_equal(str_trim_anything("..abcd.", ".", "left"), "")
   expect_equal(str_trim_anything("-ghi--", "-"), "ghi")
   expect_equal(str_trim_anything("-ghi--", "--"), "-ghi")
